# krex

A lightweight Python package providing minimal trading functions for selected exchanges, organized by exchange-specific modules.

## Contributing

Check out the [Contributing Guide](.github/CONTRIBUTING.md).

### Contributors

<a href="https://github.com/kairosresearchio/krex/graphs/contributors">
    <img src="https://contrib.rocks/image?repo=kairosresearchio/krex" />
</a>

## License

The [MIT License](LICENSE).
